@@ -4,7 +4,7 @@ from pathlib import Path
 import readcsvturbo as rct
 
 ################### Reading the first and last line from big_csv and getting a df ###################
-csv_file_path = Path("./big_csv.csv")
+csv_file_path = Path("C:\\Users\\Jordon\\Documents\\5mSalesRecords.csv")
 
 print("""
 ############## RAW PANDAS ###############
