@@ -2,7 +2,7 @@ import pandas as pd
 from pathlib import Path
 from readcsvturbo import read_csv_head, read_csv_headtail, read_csv_line, read_csv_tail
 
-path = Path("/home/donjor/5mSalesRecords.csv")
+path = Path("C:\\Users\\Jordon\\Documents\\5mSalesRecords.csv")
 
 df = read_csv_head(path)
 print(df)
